"""
Copyright 2008-2015 Free Software Foundation, Inc.
This file is part of GNU Radio

GNU Radio Companion is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

GNU Radio Companion is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
"""

from __future__ import absolute_import

from .port import Port
from .clone import PortClone



from .utils import Spec, expand, str_

DOMAIN_CONNECTION = expand(
    type=Spec(types=list, required=True, item_scheme=None),
    connect=str_,
    cpp_connect=str_,
)

DOMAIN_SCHEME = expand(
    id=Spec(types=str_, required=True, item_scheme=None),
    label=str_,
    color=str_,
    multiple_connections_per_input=bool,
    multiple_connections_per_output=bool,

    templates=Spec(types=list, required=False, item_scheme=DOMAIN_CONNECTION)
)